!----------------------------------------------------------------------
!----------------------------------------------------------------------
!	ab :     The A --> B reaction 
!----------------------------------------------------------------------
!----------------------------------------------------------------------

 SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP)
!---------- ----

! Evaluates the right hand side of the ODE

! Input arguments :
!   NDIM   :   Dimension of the ODE system 
!   U   :   State variables
!   ICP   :   Array indicating the free parameter(s)
!   PAR   :   Equation parameters

! Values to be returned :
!   F   :   The right hand side of the ODE

! Normally unused Jacobian arguments : IJAC, DFDU, DFDP (see manual)

  IMPLICIT NONE
  INTEGER NDIM, IJAC, ICP(*)
  DOUBLE PRECISION U(NDIM), PAR(*), F(NDIM), DFDU(*), DFDP(*)
  DOUBLE PRECISION u1,u2,e,D,B,beta

   D   = PAR(1)
   B   = PAR(2)
   beta= PAR(3)

   u1=U(1)
   u2=U(2)
   e=DEXP(u2)

   F(1)=-u1 + D*(1-u1)*e
   F(2)=-u2 + D*B*(1-u1)*e - beta*u2

 END SUBROUTINE FUNC
!----------------------------------------------------------------------
!----------------------------------------------------------------------

 SUBROUTINE STPNT(NDIM,U,PAR,t)
!---------- -----

! Input arguments :
!   NDIM   :   Dimension of the ODE system 

! Values to be returned :
!   U   :   A starting solution vector
!   PAR   :   The corresponding equation-parameter values
!   t   :	  Not used here

  IMPLICIT NONE
  INTEGER NDIM
  DOUBLE PRECISION U(NDIM), PAR(*), t
  DOUBLE PRECISION D, B, beta

! Initialize the equation parameters
   D   = 0.d0
   B   = 8.d0
   beta= 3.d0

   PAR(1) = D
   PAR(2) = B
   PAR(3) = beta

! Initialize the solution
   U(1)=0.d0
   U(2)=0.d0

 END SUBROUTINE STPNT
!----------------------------------------------------------------------
!----------------------------------------------------------------------
 SUBROUTINE PVLS(NDIM,U,PAR)
!---------- ----

  IMPLICIT NONE
  INTEGER, INTENT(IN) :: NDIM
  DOUBLE PRECISION, INTENT(IN) :: U(NDIM)
  DOUBLE PRECISION, INTENT(INOUT) :: PAR(*)

  DOUBLE PRECISION GETP

! Put the minimum of solution component 1 in PAR(7)
   PAR(7) = GETP('MIN',1,U)

 END SUBROUTINE PVLS
!----------------------------------------------------------------------
!----------------------------------------------------------------------
! The following subroutines are not used here,
! but they must be supplied as dummy routines

 SUBROUTINE BCND 
 END SUBROUTINE BCND

 SUBROUTINE ICND 
 END SUBROUTINE ICND

 SUBROUTINE FOPT 
 END SUBROUTINE FOPT
!----------------------------------------------------------------------
!----------------------------------------------------------------------
