!======================================================================
!======================================================================
!   pvl :  Setting functional parameter values (for Bratu's equation)
!======================================================================
!======================================================================

 SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
!---------- ---- 

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM, IJAC, ICP(*)
 DOUBLE PRECISION, INTENT(IN) :: U(NDIM), PAR(*)
 DOUBLE PRECISION, INTENT(OUT) :: F(NDIM)
 DOUBLE PRECISION, INTENT(INOUT) :: DFDU(NDIM,*), DFDP(NDIM,*)
 DOUBLE PRECISION lambda, u1, u2, e

  lambda = PAR(1)
  u1 = U(1)
  u2 = U(2)
  e = DEXP(u1) 

  F(1) = u2 
  F(2) =-lambda*e 

 END SUBROUTINE FUNC
!======================================================================

 SUBROUTINE STPNT(NDIM,U,PAR,T) 
!---------- ----- 

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM
 DOUBLE PRECISION, INTENT(INOUT) :: U(NDIM), PAR(*)
 DOUBLE PRECISION, INTENT(IN) :: T
 DOUBLE PRECISION lambda, u1, u2

  lambda = 0.
  PAR(1) = lambda

  u1 = 0.
  u2 = 0.

  U(1) = u1
  U(2) = u2

 END SUBROUTINE STPNT
!======================================================================

 SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,FB,IJAC,DBC) 
!---------- ---- 

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM, ICP(*), NBC, IJAC
 DOUBLE PRECISION, INTENT(IN) :: PAR(*), U0(NDIM), U1(NDIM)
 DOUBLE PRECISION, INTENT(OUT) :: FB(NBC)
 DOUBLE PRECISION, INTENT(INOUT) :: DBC(NBC,*)

  FB(1) = U0(1)
  FB(2) = U1(1)

 END SUBROUTINE BCND
!======================================================================

 DOUBLE PRECISION FUNCTION GETU2(U,NDX,NTST,NCOL)
!------ --------- -------- -----
 INTEGER, INTENT(IN) :: NDX,NCOL,NTST
 DOUBLE PRECISION, INTENT(IN) :: U(NDX,0:NCOL*NTST)

  GETU2 = U(2,0)

 END FUNCTION GETU2
!======================================================================

 SUBROUTINE PVLS(NDIM,U,PAR)
!---------- ----

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM
 DOUBLE PRECISION, INTENT(IN) :: U(NDIM)
 DOUBLE PRECISION, INTENT(INOUT) :: PAR(*)

 DOUBLE PRECISION, EXTERNAL :: GETP,GETU2
 INTEGER NDX,NCOL,NTST
!---------------------------------------------------------------------- 
! AUTO parameters, whose values are set in this subroutine, serve as
! "solution measures", which can be printed on the screen and in the 
! output files. One can use them to locate and save solutions, or to 
! stop the continuation, at specified values of these parameters. It 
! is important that they NEVER be used as "true" continuation parameters, 
! although they can be added as "over-specified parameters" to the 
! parameter list ICP (defined in the constants file "c.pvl" in this 
! demo). Note that OVER-SPECIFIED PARAMETERS MUST APPEAR LAST in the 
! parameter list ICP.
!
! For algebraic problems the argument "U" of PVLS(NDIM,U,PAR) is the 
! solution vector. For differential equations the argument U is also  
! the solution vector, but each of its components is then a function 
! of the independent variable (here "x") on the interval [0,1]. In this 
! case its values can be accessed indirectly by calls to GETP, as 
! illustrated below. Alternatively its values can be obtained by first 
! using GETP to get the values of NDIM, NCOL, NTST, and then calling 
! an intermediate subroutine (here called "GETU2"), in which U is 
! properly dimensioned as "U(NDIM,0:NCOL*NTST)".
!---------------------------------------------------------------------- 

! Set PAR(2) equal to the L2-norm of U(1):
  PAR(2) = GETP('NRM',1,U)

! Set PAR(3) equal to the minimum of U(2):
  PAR(3) = GETP('MIN',2,U)

! Set PAR(4) equal to the value of U(2) at the left boundary x=0:
  PAR(4) = GETP('BV0',2,U)

! Another way: set PAR(5) equal to the value of U(2) at x=0:
  NDX  = NINT(GETP('NDX',0,U))
  NTST = NINT(GETP('NTST',0,U))
  NCOL = NINT(GETP('NCOL',0,U))

  PAR(5) = GETU2(U,NDX,NTST,NCOL)
! (The function "GETU2" is defined above.)

!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
!             List of possible arguments of GETP
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
! The first argument of GETP can be one of the following:

!   NRM  : L2-norm
!   MIN  : minimum
!   MAX  : maximum
!   INT  : integral
!   BV0  : boundary value at x=0,
!   BV1  : boundary value at x=1.
!   MNT  : the value of the independent variable where the minimum occurs
!   MXT  : the value of the independent variable where the maximum occurs
!   NDIM : the original dimension of the problem
!   NDX  : the effective dimension of the problem
!   NTST : the number of mesh intevals NTST
!   NCOL : the number of collocation points NCOL
!   NBC  : the effective number of boundary conditions
!   NINT : the effective number of integral constraints
!   DTM  : the size of the i-th mesh interval, for i between 1 and NTST
!   WINT : the integration weights, for i between 1 and NCOL
!   STP  : the pseudo-arclength step size used.
!   FLD  : the "fold function", which vanishes at folds.
!   BIF  : the "bifurcation function", which vanishes at bifurcation points.
!   HBF  : the "Hopf function", which vanishes at Hopf bifurcations.
!   SPB  : a function that vanishes at secondary periodic bifurcations.
!   EIG  : eigenvalues/multipliers, i=1,...,2*NDIM, alternating real/imag parts.
!   STA :  the number of stable eigenvalues/multipliers.

 END SUBROUTINE PVLS
!======================================================================

 SUBROUTINE ICND
 END SUBROUTINE ICND

 SUBROUTINE FOPT 
 END SUBROUTINE FOPT
!======================================================================
!======================================================================
